# Open Traffic Generator Abstract Python Package
[![Validated](https://travis-ci.org/open-traffic-generator/abstract-python-package.svg?branch=master)](https://travis-ci.org/open-traffic-generator/abstract-python-package)
[![pypi](https://img.shields.io/pypi/v/abstract-open-traffic-generator.svg)](https://pypi.org/project/abstract-open-traffic-generator)
[![python](https://img.shields.io/pypi/pyversions/abstract-open-traffic-generator.svg)](https://pypi.python.org/pypi/abstract-open-traffic-generator)
[![license](https://img.shields.io/badge/license-MIT-green.svg)](https://en.wikipedia.org/wiki/MIT_License)

This package is an autogenerated abstract python package based on the 
Open Traffic Generator models.

